// Demo 10

//  The Continuing Saga of Sally's Lemonade Stand
//  A Java Application and Keeping a Running Total Demo
//
//          by Charles W. Neville, 1998
//       Copyright Charles W. Neville, 1998

// Scenario: Little Sally is a very precocious five year old who runs a 
// lemonade stand.  She is also your kid sister.  In our last demo (demo 9),
// you rewrote your screen based Java application for her as a Java Applet
// so she could keep track of her daily sales receipts while enjoying the
// advantages of a point-and-click Graphic User Interface.  With an eye toward 
// allowing her to SAVE her days totals to a file (something Java security 
// normally does not allow Applets to do), you decide to convert your Java
// Applet so it runs as a Java Application.  Later (not now), you will add
// the file saving stuff.

import java.awt.*;
import java.awt.event.*;
import CloseAndExit;  // our helper class so we can exit the application
                      // by clicking on the close box.

// no need to import java.io.* because we get our input from TextFields,
// not from the keyboard in a screen-based application.  In some sense,
// java.awt.event.* takes the place of java.io here.

class SallyApplication extends Frame implements ActionListener {

   int salePrice, count, total;

   Label prompt;     // prompt on Applet Panel for TextField input
   TextField input;  // where Sally enters current sale price

   // no need for a stopping signal, so no need for
   // declaration final int stoppingSignal = -999;

   // Constructor for class SallyApplication
   //    Applications always have a constructor method which is called by
   //    by main.  So the constructor is a good place to do initializations.
   public SallyApplication() {

      // A SallyApplication object is a Frame with added structure.
      //   Unfortunately, the default LayoutManager for a Frame is not well
      //   suited a Frame which contains several components and on which we
      //   plan to directly draw.  (The LayoutManager determines how
      //   components are placed on the Frame.)  Thus we have to change the 
      //   LayoutManager to the one used by Applets and Panels.  This is 
      //   arcane, but necessary.

      // Change LayoutManager to one used by Applets and Panels
      setLayout(new FlowLayout() );

       // initialize variables
       count = 0;  // always set count to 0 when you start counting
       total = 0;  // always set total to 0 when you start keeping a
                   // running total

       salePrice = 0;

       // create new instances of Label and TextField classes
       //        (Label and TextField objects).
       prompt = new Label ( "Sale Price:" );
       input = new TextField(9);

       // add Label and TextField to the application Frame
       add( prompt );
       add( input );

      // Register this object as the ActionListener (ActionEvent processor)
      //   for input.  (An action event happens, for example, when the
      //   Enter key is pressed.  Leaving this out causes your application not 
      //   to respond when the user presses the Enter key.
      input.addActionListener(this);  // this is a keyword referring to
                                      // the current object, ie. this object. 

      // Register an instance of CloseAndExit as a
      //   window event listener so we can close the Frame and exit
      //   the app gracefully
      addWindowListener( new CloseAndExit() );
   }

   public void paint( Graphics g ) {

      g.drawString( "Sales Count: " + count, 25, 140 );
      g.drawString( "Total Sales: " + total, 25, 160 );
      g.drawString( "Keep Up the Good Work, Sally!", 25, 180 );
   }

   // When Sally presses the Enter key while in TextField input, we
   // do this to process her input.
   public void actionPerformed( ActionEvent e ) {

       // read the salePrice from TextField input
       salePrice = Integer.parseInt(input.getText());

       // because we don't want to reuse a variable several times in paint,
       // it is better to do the calculations here in actionPerformed, rather
       // than in paint as we did in the ArithOps demos (demos 6 and 7).
       total = total + salePrice;
       count = count + 1;

       // force Applet Panel to be repainted so results will be painted.
       repaint();
   }

   public static void main(String[] args) {

     SallyApplication sally;

     // Construct an instance of the SallyApplication class
     // (a SallyApplication object).
     sally = new SallyApplication();

     // A SallyApplication object is a Frame with additional structure.
     // Set the Frame's size to 350 pixels by 400 pixels,
     //   and make the Frame visible (show the Frame).
     sally.setSize(375, 400);
     sally.setVisible(true);
   }
   
}